==> haskell-test-framework-0.8.2.2-183-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework
version:              0.8.2.2
visibility:           public
id:                   test-framework-0.8.2.2-KgR41U2LlpcHoPKtOjhgl0
key:                  test-framework-0.8.2.2-KgR41U2LlpcHoPKtOjhgl0
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:
    Framework for running and organising tests, with HUnit and QuickCheck support

description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.

category:             Testing
abi:                  4b9bdbfe51d42cc9008afecdcceafbed
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed

hidden-modules:
    Test.Framework.Core Test.Framework.Improving
    Test.Framework.Runners.Console.Colors
    Test.Framework.Runners.Console.ProgressBar
    Test.Framework.Runners.Console.Run
    Test.Framework.Runners.Console.Statistics
    Test.Framework.Runners.Console.Table
    Test.Framework.Runners.Console.Utilities
    Test.Framework.Runners.Core Test.Framework.Runners.Processors
    Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
    Test.Framework.Runners.TimedConsumption
    Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
    Test.Framework.Utilities

import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-0.8.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-0.8.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-0.8.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework
hs-libraries:         HStest-framework-0.8.2.2-KgR41U2LlpcHoPKtOjhgl0
depends:
    ansi-terminal-1.0.2-EWRmoRkCD6N8oQC0Fs2AaT
    ansi-wl-pprint-1.0.2-2tuDzcWFgCUClh2ckuzVfg base-4.17.2.1
    containers-0.6.7 hostname-1.0-LeTF2MpavibDHBTJAkCOwY
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    random-1.2.1.3-AItr1WcsEfaHebdgTnBQBQ
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9 time-1.12.2
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:
    /usr/share/doc/haskell-test-framework/html/test-framework.haddock

haddock-html:         /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-0.8.2.2-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework
version:              0.8.2.2
visibility:           public
id:                   test-framework-0.8.2.2-FQYqW1xBRBv2uG8qFNTvf9
key:                  test-framework-0.8.2.2-FQYqW1xBRBv2uG8qFNTvf9
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:
    Framework for running and organising tests, with HUnit and QuickCheck support

description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.

category:             Testing
abi:                  ed10942f405cbb8609440b119037b5ad
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed

hidden-modules:
    Test.Framework.Core Test.Framework.Improving
    Test.Framework.Runners.Console.Colors
    Test.Framework.Runners.Console.ProgressBar
    Test.Framework.Runners.Console.Run
    Test.Framework.Runners.Console.Statistics
    Test.Framework.Runners.Console.Table
    Test.Framework.Runners.Console.Utilities
    Test.Framework.Runners.Core Test.Framework.Runners.Processors
    Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
    Test.Framework.Runners.TimedConsumption
    Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
    Test.Framework.Utilities

import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-0.8.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-0.8.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-0.8.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework
hs-libraries:         HStest-framework-0.8.2.2-FQYqW1xBRBv2uG8qFNTvf9
depends:
    ansi-terminal-1.0.2-HBeoENQnxizF4CvHZENnzA
    ansi-wl-pprint-1.0.2-A53tL5ipekoBgE3H75HBl4 base-4.17.2.1
    containers-0.6.7 hostname-1.0-LeTF2MpavibDHBTJAkCOwY
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    random-1.2.1.3-4qsyrxcHgJtHIq1RwsIwfO
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9 time-1.12.2
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:
    /usr/share/doc/haskell-test-framework/html/test-framework.haddock

haddock-html:         /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
